Package: labdsv
Version: 2.3-1
Title: Ordination and Multivariate Analysis for Ecology
Authors@R: person(given = c("David", "W."),
                      family = "Roberts",
                      role = c("aut", "cre"),
                      email = "droberts@montana.edu")
Depends: R (>= 3.0), mgcv
Imports: cluster, Rtsne, MASS
Suggests: fso
Enhances: vegan
Description: A variety of ordination and community analyses
   useful in analysis of data sets in community ecology.  
   Includes many of the common ordination methods, with 
   graphical routines to facilitate their interpretation, 
   as well as several novel analyses.
License: GPL (>= 2)
NeedsCompilation: yes
Repository: CRAN
Author: David W. Roberts [aut, cre]
Maintainer: David W. Roberts <droberts@montana.edu>
Packaged: 2026-04-06 02:49:43 UTC; dvrbts
Date/Publication: 2026-04-06 14:30:02 UTC
