# Export all names
export(
# data handling and generating
 reconcile,
 matrify,
 dematrify,
 rndcomm,
# data editing
 dropplt,
 dropspc,
 factorize,
 defactorize,
 ordcomm,
 gsr,
# transformations and standardizations
 abundtrans,
 convex,
 samptot,
 spcmax,
 hellinger,
# disimilarity functions,
 dsvdis,
 disana,
 rnddist,
 neighbors,
# dissimilarity conversion routines
 metrify,
 as.metric,
 is.metric,
 euclidify,
 as.euclidean,
 stepdist,
# data viewing
 abuocc,
 vegtab,
 dsvls,
 dga,
 raretaxa,
# ordination functions
 pca,
 pco,
 nmds,
 bestnmds,
 tsne,
 besttsne,
 as.dsvord,
# ordination graphics functions
 surf,
 ellip,
 plotid,
 specid,
 hilight,
 chullord,
 thull,
 varplot,
 loadings,
  scores,
# ordination analysis functions
 density,
 ordcomp,
 orddist,
 ordpart,
 ordtest,
 ordneighbors,
 predict,
 calibrate,
# classification utilities
 concov,
 const,
 homoteneity,
 importance,
 isamic,
 spcdisc,
 envrtest,
 ccm,
# compositional specificity
 compspec,
 indval
)


# Import all packages listed as Imports or Depends
  import("mgcv")
  importFrom("grDevices", "chull", "rainbow")
  importFrom("graphics", "abline", "barplot", "contour", "identify",
             "image", "lines", "locator", "plot", "points", "polygon",
             "text", "arrows")
  importFrom("stats", "as.dist", "binomial", "cmdscale", "cor", "dist",
             "gaussian", "poisson", "prcomp", "predict", "quantile",
             "runif", "smooth", "AIC","var","loadings")
  importFrom("utils", "write.table", "tail","txtProgressBar",
              "setTxtProgressBar")
  importFrom("MASS", "isoMDS")
  importFrom("cluster", "ellipsoidhull")
  importFrom("Rtsne", "Rtsne")
  

# Register all generic methods

S3method(plot,dsvord)
S3method(plot,pco)
S3method(plot,nmds)
S3method(chullord,dsvord)
S3method(density,dsvord)
S3method(hilight,dsvord)
S3method(ordpart,dsvord)
S3method(plotid,dsvord)
S3method(points,dsvord)
S3method(surf,dsvord)
S3method(thull,dsvord)
S3method(ellip,dsvord)
S3method(predict,dsvord)
S3method(calibrate,dsvord)

S3method(indval,default)

S3method(plot,compspec)
S3method(plot,thull)

S3method(summary,indval)
S3method(summary,pca)
S3method(summary,dsvord)
S3method(summary,dist)
S3method(summary,thull)
S3method(summary,clustering)
S3method(summary,compspec)


S3method(varplot,pca)
S3method(plot,pca)
S3method(loadings,pca)
S3method(scores,pca)

S3method(print,abuocc)

useDynLib(labdsv)
