\name{labdsv.internal}
\alias{plotid}
\alias{specid}
\alias{surf}
\alias{hilight}
\alias{chullord}
\alias{shannon}
\alias{pip}
\alias{density}
\title{LabDSV Internal Functions}
\description{These functions establish several generic functions,
and are not intended to be called directly}
\keyword{internal}
